@@ -3,42 +3,49 @@ package MooseX::ClassAttribute;
 use strict;
 use warnings;
 
-our $VERSION = '0.10';
+our $VERSION   = '0.11';
 our $AUTHORITY = 'cpan:DROLSKY';
 
-use Moose 0.89 ();
+use Moose 0.97 ();
 use Moose::Exporter;
-use MooseX::ClassAttribute::Role::Meta::Class;
+use MooseX::ClassAttribute::Trait::Class;
+use MooseX::ClassAttribute::Trait::Role;
+use MooseX::ClassAttribute::Trait::Application::ToClass;
+use MooseX::ClassAttribute::Trait::Application::ToRole;
+use MooseX::ClassAttribute::Trait::Application::ToInstance;
 
-Moose::Exporter->setup_import_methods
-    ( with_caller => [ 'class_has' ] );
+Moose::Exporter->setup_import_methods( with_meta => ['class_has'] );
 
-
-sub init_meta
-{
+sub init_meta {
     shift;
     my %p = @_;
 
-    Moose->init_meta(%p);
-
-    return
-        Moose::Util::MetaRole::apply_metaclass_roles
-            ( for_class       => $p{for_class},
-              metaclass_roles => [ 'MooseX::ClassAttribute::Role::Meta::Class' ],
-            );
+    return Moose::Util::MetaRole::apply_metaclass_roles(
+        for             => $p{for_class},
+        class_metaroles => {
+            class => ['MooseX::ClassAttribute::Trait::Class'],
+        },
+        role_metaroles => {
+            role => ['MooseX::ClassAttribute::Trait::Role'],
+            application_to_class =>
+                ['MooseX::ClassAttribute::Trait::Application::ToClass'],
+            application_to_role =>
+                ['MooseX::ClassAttribute::Trait::Application::ToRole'],
+            application_to_instance => [
+                'MooseX::ClassAttribute::Trait::Application::ToInstance'
+            ],
+        },
+    );
 }
 
-sub class_has
-{
-    my $caller  = shift;
+sub class_has {
+    my $meta    = shift;
     my $name    = shift;
     my %options = @_;
 
     my $attrs = ref $name eq 'ARRAY' ? $name : [$name];
 
-    Class::MOP::class_of($caller)
-        ->add_class_attribute( $_, %options )
-            for @{ $attrs };
+    $meta->add_class_attribute( $_, %options ) for @{$attrs};
 }
 
 1;
@@ -73,38 +80,38 @@ MooseX::ClassAttribute - Declare class attributes Moose-style
 
     My::Class->Cache()->{thing} = ...;
 
-
 =head1 DESCRIPTION
 
 This module allows you to declare class attributes in exactly the same
 way as object attributes, using C<class_has()> instead of C<has()>.
 
 You can use any feature of Moose's attribute declarations, including
-overriding a parent's attributes, delegation (C<handles>), and
-attribute metaclasses, and it should just work. The one exception is
-the "required" flag, which is not allowed for class attributes.
+overriding a parent's attributes, delegation (C<handles>), attribute traits,
+etc. All features should just work. The one exception is the "required" flag,
+which is not allowed for class attributes.
 
 The accessor methods for class attribute may be called on the class
 directly, or on objects of that class. Passing a class attribute to
-the constructor will not set it.
+the constructor will not set that attribute.
 
 =head1 FUNCTIONS
 
 This class exports one function when you use it, C<class_has()>. This
 works exactly like Moose's C<has()>, but it declares class attributes.
 
-One little nit is that if you include C<no Moose> in your class, you
-won't remove the C<class_has()> function. To do that you must include
-C<no MooseX::ClassAttribute> as well.
+One little nit is that if you include C<no Moose> in your class, you won't
+remove the C<class_has()> function. To do that you must include C<no
+MooseX::ClassAttribute> as well. Or you can just use L<namespace::autoclean>
+instead.
 
 =head2 Implementation and Immutability
 
 This module will add a role to your class's metaclass, See
-L<MooseX::ClassAttribute::Role::Meta::Class> for details. This role
+L<MooseX::ClassAttribute::Trait::Class> for details. This role
 provides introspection methods for class attributes.
 
 Class attributes themselves do the
-L<MooseX::ClassAttribute::Role::Meta::Attribute> role.
+L<MooseX::ClassAttribute::Trait::Attribute> role.
 
 There is also a L<MooseX::ClassAttribute::Meta::Method::Accessor>
 which provides part of the inlining implementation for class
@@ -114,7 +121,14 @@ attributes.
 
 This module should work with most attribute metaclasses and traits,
 but it's possible that conflicts could occur. This module has been
-tested to work with C<MooseX::AttributeHelpers>.
+tested to work with Moose's native traits.
+
+=head2 Class Attributes in Roles
+
+You can add a class attribute to a role. When that role is applied to a class,
+the class will have the relevant class attributes added. Note that attribute
+defaults will be calculated when the class attribute is composed into the
+class.
 
 =head1 DONATIONS
 
@@ -150,7 +164,7 @@ automatically be notified of progress on your bug as I make changes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007-2008 Dave Rolsky, All Rights Reserved.
+Copyright 2007-2010 Dave Rolsky, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
